@@ -21,12 +21,13 @@
 #include "TransactionModel.h"
 
 // Qt includes
-#include <QtCore/QDebug>
-#include <QtCore/QMetaProperty>
+#include <QDebug>
+#include <QMetaProperty>
 #include <KLocalizedString>
 
 // Own includes
 #include "resources/AbstractResource.h"
+#include "libdiscover_debug.h"
 
 Q_GLOBAL_STATIC(TransactionModel, globalTransactionModel)
 
@@ -108,9 +109,9 @@ QVariant TransactionModel::data(const QModelIndex &index, int role) const
         }
         break;
     case TransactionRole:
-        return qVariantFromValue<QObject*>(trans);
+        return QVariant::fromValue<QObject*>(trans);
     case ResourceRole:
-        return qVariantFromValue<QObject*>(trans->resource());
+        return QVariant::fromValue<QObject*>(trans->resource());
     }
 
     return QVariant();
@@ -171,9 +172,10 @@ void TransactionModel::addTransaction(Transaction *trans)
 void TransactionModel::removeTransaction(Transaction *trans)
 {
     Q_ASSERT(trans);
+    trans->deleteLater();
     int r = m_transactions.indexOf(trans);
     if (r<0) {
-        qWarning() << "transaction not part of the model already" << trans;
+        qCWarning(LIBDISCOVER_LOG) << "transaction not part of the model" << trans;
         return;
     }
 
@@ -186,7 +188,6 @@ void TransactionModel::removeTransaction(Transaction *trans)
     emit transactionRemoved(trans);
     if (m_transactions.isEmpty())
         emit lastTransactionFinished();
-    trans->deleteLater();
 }
 
 void TransactionModel::transactionChanged(int role)
